Dice definitions and face values. Dice value objects.
This module contains the serializable representation of dice and die faces. Built-in dice use numeric faces; custom dice may mix numeric and text faces.
Structs
- Die
- A die with a stable name and ordered set of faces.
Enums
- DieKind
- Classifies whether a die is provided by the crate or supplied by a caller.
- Face
Value - A single face on a die.
Constants
- CUSTOM_
PREFIX - Prefix used for canonical custom die names.
Functions
- builtin_
dice - Returns the built-in numeric dice.