RollBatchResult

Struct RollBatchResult 

pub struct RollBatchResult {
    pub rolls: Vec<DieRoll>,
    pub integer_sum: Option<i64>,
}
Result of rolling multiple dice.

Fields

rolls: Vec<DieRoll>

Individual roll results in input order.

integer_sum: Option<i64>

Sum of integer faces when at least one integer face was rolled.

Text faces are excluded. This is None when the batch contains no integer face values.