TrayResult

Struct TrayResult 

pub struct TrayResult {
    pub tray_name: String,
    pub slots: Vec<SlotResult>,
    pub integer_sum: Option<i64>,
}
Snapshot result for a tray.

Fields

tray_name: String

Tray name.

slots: Vec<SlotResult>

Current slot snapshots in tray order.

integer_sum: Option<i64>

Sum of current integer slot values when any are present.

Text faces and empty slots are excluded. This is None when the tray has no current integer values.