Tray

Struct Tray 

pub struct Tray {
    pub name: String,
    pub slots: Vec<TraySlot>,
    pub next_slot_id: u32,
}
A named collection of dice slots.

Fields

name: String

Tray name.

slots: Vec<TraySlot>

Slots currently assigned to the tray.

next_slot_id: u32

Next slot identifier to assign.

Slot identifiers are auto-incrementing and are not reused after a slot is removed from the tray.

Implementations

Source

impl Tray

pub fn new(name: String) -> Self

Creates an empty tray with slot identifiers starting at 1.